@@ -269,7 +269,7 @@ Account *AccountManager::registerAccount(Account *account)
     }
 
     d->accounts.append(account);
-    qSort(d->accounts.begin(), d->accounts.end(), compareAccountsByPriority);
+    std::sort(d->accounts.begin(), d->accounts.end(), compareAccountsByPriority);
 
     // Connect to the account's status changed signal
     connect(account->myself(), SIGNAL(onlineStatusChanged(Kopete::Contact *,
@@ -277,7 +277,7 @@ Account *AccountManager::registerAccount(Account *account)
             this, SLOT(slotAccountOnlineStatusChanged(Kopete::Contact *,
                                                       const Kopete::OnlineStatus&,const Kopete::OnlineStatus&)));
 
-    connect(account, SIGNAL(accountDestroyed(const Kopete::Account *)), this, SLOT(unregisterAccount(const Kopete::Account *)));
+    connect(account, SIGNAL(accountDestroyed(const Kopete::Account*)), this, SLOT(unregisterAccount(const Kopete::Account*)));
 
     if (!account->identity()) {
         // the account's Identity must be set here instead of in the Kopete::Account ctor, because there the
@@ -349,7 +349,7 @@ void AccountManager::removeAccount(Account *account)
 void AccountManager::save()
 {
     //qCDebug(LIBKOPETE_LOG) ;
-    qSort(d->accounts.begin(), d->accounts.end(), compareAccountsByPriority);
+    std::sort(d->accounts.begin(), d->accounts.end(), compareAccountsByPriority);
 
     for (QListIterator<Account *> it(d->accounts); it.hasNext();) {
         Account *a = it.next();
@@ -364,8 +364,8 @@ void AccountManager::save()
 
 void AccountManager::load()
 {
-    connect(PluginManager::self(), SIGNAL(pluginLoaded(Kopete::Plugin *)),
-            this, SLOT(slotPluginLoaded(Kopete::Plugin *)));
+    connect(PluginManager::self(), SIGNAL(pluginLoaded(Kopete::Plugin*)),
+            this, SLOT(slotPluginLoaded(Kopete::Plugin*)));
 
     // Iterate over all groups that start with "Account_" as those are accounts
     // and load the required protocols if the account is enabled.
