@@ -18,41 +18,36 @@
 
 #include "kopetetask.h"
 
-#include <kdebug.h>
-
-namespace Kopete
-{
+#include "libkopete_debug.h"
 
+namespace Kopete {
 class Task::Private
 {
 public:
 };
 
 Task::Task(QObject *parent)
- : KCompositeJob(parent), d( new Private )
+    : KCompositeJob(parent)
+    , d(new Private)
 {
 }
 
 Task::~Task()
 {
-	delete d;
+    delete d;
 }
 
 void Task::addSubTask(KJob *task)
 {
-	addSubjob(task);
+    addSubjob(task);
 }
 
 void Task::start()
 {
-	kDebug(14010) << "Executing children tasks for this task.";
-	KJob *subTask = 0;
-	foreach( subTask, subjobs() )
-	{
-		subTask->start();
-	}
+    qCDebug(LIBKOPETE_LOG) << "Executing children tasks for this task.";
+    KJob *subTask = 0;
+    foreach (subTask, subjobs()) {
+        subTask->start();
+    }
 }
-
 }
-
-#include "kopetetask.moc"
