@@ -17,15 +17,15 @@
 
 #include "historylogger.h"
 
-#include <QtCore/QRegExp>
-#include <QtCore/QFile>
-#include <QtCore/QDir>
-#include <QtCore/QDateTime>
-#include <QtCore/QTimer>
-#include <QtCore/QTextStream>
-#include <QtCore/QList>
-#include <QtCore/QDate>
-#include <QtGui/QTextDocument>
+#include <QRegExp>
+#include <QFile>
+#include <QDir>
+#include <QDateTime>
+#include <QTimer>
+#include <QTextStream>
+#include <QList>
+#include <QDate>
+#include <QTextDocument>
 
 #include <kdebug.h>
 
@@ -68,7 +68,7 @@ HistoryLogger::HistoryLogger(Kopete::MetaContact *m, QObject *parent)
     m_filterRegExp = false;
 
     //the contact may be destroyed, for example, if the contact changes its metacontact
-    connect(m_metaContact, SIGNAL(destroyed(QObject *)), this, SLOT(slotMCDeleted()));
+    connect(m_metaContact, SIGNAL(destroyed(QObject*)), this, SLOT(slotMCDeleted()));
 
     setPositionToLast();
 }
@@ -87,7 +87,7 @@ HistoryLogger::HistoryLogger(Kopete::Contact *c, QObject *parent)
     m_filterRegExp = false;
 
     //the contact may be destroyed, for example, if the contact changes its metacontact
-    connect(m_metaContact, SIGNAL(destroyed(QObject *)), this, SLOT(slotMCDeleted()));
+    connect(m_metaContact, SIGNAL(destroyed(QObject*)), this, SLOT(slotMCDeleted()));
 
     setPositionToLast();
 }
