@@ -2,12 +2,12 @@
     Kopete Groupwise Protocol
     getstatustask.h - fetch a contact's details from the server
 
-    Copyright (c) 2004      SUSE Linux AG	 	 http://www.suse.com
-    
+    Copyright (c) 2004      SUSE Linux AG	     http://www.suse.com
+
     Based on Iris, Copyright (C) 2003  Justin Karneges <justin@affinix.com>
 
     Kopete (c) 2002-2004 by the Kopete developers <kopete-devel@kde.org>
- 
+
     *************************************************************************
     *                                                                       *
     * This library is free software; you can redistribute it and/or         *
@@ -29,16 +29,16 @@
 */
 class GetStatusTask : public RequestTask
 {
-Q_OBJECT
+    Q_OBJECT
 public:
-	GetStatusTask(Task* parent);
-	~GetStatusTask();
-	void userDN( const QString & dn );
-	bool take( Transfer * transfer );
-signals:
-	void gotStatus( const QString & contactId, quint16 status, const QString & statusText );
+    GetStatusTask(Task *parent);
+    ~GetStatusTask();
+    void userDN(const QString &dn);
+    bool take(Transfer *transfer) Q_DECL_OVERRIDE;
+Q_SIGNALS:
+    void gotStatus(const QString &contactId, quint16 status, const QString &statusText);
 private:
-	QString m_userDN;
+    QString m_userDN;
 };
 
 #endif
