@@ -17,9 +17,9 @@
 
 #include "jabbergroupmembercontact.h"
 
-#include <kdebug.h>
-#include <klocale.h>
-#include <kfiledialog.h>
+#include "jabber_protocol_debug.h"
+#include <KLocalizedString>
+#include <QFileDialog>
 #include "jabberprotocol.h"
 #include "jabberaccount.h"
 #include "jabberfiletransfer.h"
@@ -64,7 +64,7 @@ JabberGroupMemberContact::~JabberGroupMemberContact ()
 	}
 }
 
-QList<KAction*> *JabberGroupMemberContact::customContextMenuActions ()
+QList<QAction *> *JabberGroupMemberContact::customContextMenuActions ()
 {
 
 	return 0;
@@ -104,29 +104,29 @@ void JabberGroupMemberContact::slotChatSessionDeleted ()
 void JabberGroupMemberContact::handleIncomingMessage ( const XMPP::Message &message )
 {
 	// message type is always chat in a groupchat
-	QString viewType = "kopete_chatwindow";
-	Kopete::Message *newMessage = 0L;
+	QString viewType = QStringLiteral("kopete_chatwindow");
+	Kopete::Message *newMessage = nullptr;
 
-	kDebug (JABBER_DEBUG_GLOBAL) << "Received Message Type:" << message.type ();
+	qDebug (JABBER_PROTOCOL_LOG) << "Received Message Type:" << message.type ();
 
 	Kopete::ChatSession *kmm = manager( Kopete::Contact::CanCreate );
 	if(!kmm)
 		return;
 
-	if ( message.type () != "error" )
+	if ( message.type () != QLatin1String("error") )
 	{
 		if (!message.invite().isEmpty())
 		{
 			/*QString room=message.invite();
 			QString originalBody=message.body().isEmpty() ? QString() :
-				i18n( "The original message is : <i>\" %1 \"</i><br />" , Qt::escape(message.body()));
+				i18n( "The original message is : <i>\" %1 \"</i><br />" , message.body().toHtmlEscaped());
 			QString mes=i18n("<qt><i>%1</i> has invited you to join the conference <b>%2</b><br />%3<br />"
 			                 "If you want to accept and join, just <b>enter your nickname</b> and press OK.<br />"
 			                 "If you want to decline, press Cancel.</qt>",
 			                 message.from().full(), room , originalBody);
 			
 			bool ok=false;
-			QString futureNewNickName = KInputDialog::getText( i18n( "Invited to a conference - Jabber Plugin" ),
+            QString futureNewNickName = QInputDialog::getText( i18n( "Invited to a conference - Jabber Plugin" ),
 				mes, QString() , &ok , (mManager ? dynamic_cast<QWidget*>(mManager->view(false)) : 0) );
 			if ( !ok || !account()->isConnected() || futureNewNickName.isEmpty() )
 				return;
@@ -204,7 +204,7 @@ void JabberGroupMemberContact::handleIncomingMessage ( const XMPP::Message &mess
 	Kopete::ContactPtrList contactList = kmm->members();
 
 	// check for errors
-	if ( message.type () == "error" )
+	if ( message.type () == QLatin1String("error") )
 	{
 		newMessage = new Kopete::Message( this, contactList );
 		newMessage->setTimestamp( message.timeStamp() );
@@ -224,17 +224,17 @@ void JabberGroupMemberContact::handleIncomingMessage ( const XMPP::Message &mess
 
 		if( !message.xencrypted().isEmpty () )
 		{
-			body = QString ("-----BEGIN PGP MESSAGE-----\n\n") + message.xencrypted () + QString ("\n-----END PGP MESSAGE-----\n");
+			body = QStringLiteral ("-----BEGIN PGP MESSAGE-----\n\n") + message.xencrypted () + QStringLiteral ("\n-----END PGP MESSAGE-----\n");
 		}
 		else if( !message.xsigned().isEmpty () )
 		{
-			body = QString ("-----BEGIN PGP MESSAGE-----\n\n") + message.xsigned () + QString ("\n-----END PGP MESSAGE-----\n");
+			body = QStringLiteral ("-----BEGIN PGP MESSAGE-----\n\n") + message.xsigned () + QStringLiteral ("\n-----END PGP MESSAGE-----\n");
 		}
 
 		// convert XMPP::Message into Kopete::Message
 		if( message.containsHTML() )
 		{
-			kDebug ( JABBER_DEBUG_GLOBAL ) << "Received a xHTML message";
+			qCDebug(JABBER_PROTOCOL_LOG) << "Received a xHTML message";
 			newMessage = new Kopete::Message ( this, contactList );
 			newMessage->setTimestamp( message.timeStamp() );
 			newMessage->setHtmlBody( message.html().toString() );
@@ -245,7 +245,7 @@ void JabberGroupMemberContact::handleIncomingMessage ( const XMPP::Message &mess
 		}
 		else if ( !body.isEmpty () )
 		{
-			kDebug ( JABBER_DEBUG_GLOBAL ) << "Received a plain text message";
+			qCDebug(JABBER_PROTOCOL_LOG) << "Received a plain text message";
 			newMessage = new Kopete::Message ( this, contactList );
 			newMessage->setTimestamp( message.timeStamp() );
 			newMessage->setPlainBody( body );
@@ -291,15 +291,15 @@ QString JabberGroupMemberContact::lastReceivedMessageId () const
 	return mLastReceivedMessageId;
 }
 
-void JabberGroupMemberContact::sendFile ( const KUrl &sourceURL, const QString &/*fileName*/, uint /*fileSize*/ )
+void JabberGroupMemberContact::sendFile ( const QUrl &sourceURL, const QString &/*fileName*/, uint /*fileSize*/ )
 {
 	QString filePath;
 
 	// if the file location is null, then get it from a file open dialog
 	if ( !sourceURL.isValid () )
-		filePath = KFileDialog::getOpenFileName( KUrl(), "*", 0L, i18n ( "Kopete File Transfer" ) );
+		filePath = QFileDialog::getOpenFileName(0L, i18n ( "Kopete File Transfer" ) ,  QString(), QStringLiteral("*"));
 	else
-		filePath = sourceURL.path(KUrl::RemoveTrailingSlash);
+		filePath = sourceURL.adjusted(QUrl::StripTrailingSlash).path();
 
 	QFile file ( filePath );
 
@@ -311,5 +311,3 @@ void JabberGroupMemberContact::sendFile ( const KUrl &sourceURL, const QString &
 
 }
 
-
-#include "jabbergroupmembercontact.moc"
