@@ -20,7 +20,7 @@
 #ifndef CHATROOMHANDLER_H
 #define CHATROOMHANDLER_H
 
-#include <QtCore/QObject>
+#include <QObject>
 #include "oscartypes.h"
 
 #include "liboscar_export.h"
@@ -45,7 +45,7 @@ public Q_SLOTS:
 	void reject();
 	void accept();
 
-signals:
+Q_SIGNALS:
 	void joinChatRoom( const QString& roomName, int exchange );
 
 private:
