@@ -21,12 +21,10 @@
 #include <QList>
 #include <kdebug.h>
 
-
 #include "transfer.h"
 #include "connection.h"
 #include "rateclass.h"
 
-
 class RateClassManagerPrivate
 {
 public:
@@ -128,12 +126,11 @@ void RateClassManager::transferReady( Transfer* t )
 	d->client->forcedSend( t );
 }
 
-
 RateClass* RateClassManager::findRateClass( SnacTransfer* st ) const
 {
 	SNAC s = st->snac();
 	//kDebug(OSCAR_RAW_DEBUG) << "Looking for SNAC " << s.family << ", " << s.subtype;
-	RateClass* rc = 0L;
+	RateClass* rc = nullptr;
 	QList<RateClass*>::const_iterator it;
 	QList<RateClass*>::const_iterator rcEnd = d->classList.constEnd();
 
@@ -173,6 +170,3 @@ int RateClassManager::timeToInitialLevel( SNAC s )
 	return 0;
 }
 
-#include "rateclassmanager.moc"
-
-//kate: tab-width 4; indent-mode csands;
