@@ -24,7 +24,6 @@
 #include "transfer.h"
 #include "oscarmessageplugin.h"
 
-
 SendMessageTask::SendMessageTask(Task* parent): Task(parent)
 {
 	m_autoResponse = false;
@@ -32,7 +31,6 @@ SendMessageTask::SendMessageTask(Task* parent): Task(parent)
 	m_ip = 0;
 }
 
-
 SendMessageTask::~SendMessageTask()
 {
 }
@@ -56,7 +54,7 @@ void SendMessageTask::onGo()
 {
 	if ( m_message.textArray().isEmpty() && m_message.channel() == 1 )
 	{ //channel 1 shouldn't be sending blanks
-		setError(-1, "No message to send");
+		setError(-1, QStringLiteral("No message to send"));
 		return;
 	}
 
@@ -99,7 +97,6 @@ void SendMessageTask::onGo()
 	b->addByte( m_message.receiver().length() );
 	b->addString( m_message.receiver().toLatin1() );
 
-
 	if ( snacSubfamily == 0x0006 )
 	{
 		/* send a regular message */
@@ -148,14 +145,12 @@ void SendMessageTask::onGo()
 	setSuccess(true);
 }
 
-
 void SendMessageTask::addBasicTLVs( Buffer* b )
 {
 	Q_UNUSED( b );
 	//TODO add stuff like user class, user status, online time, etc TLVS
 }
 
-
 void SendMessageTask::addChannel1Data( Buffer* b )
 {
 	Buffer tlv2buffer;
@@ -242,7 +237,6 @@ void SendMessageTask::addChannel2Data( Buffer* b )
 			}
 		}
 
-
 		/* now comes the important TLV 0x2711 */
 		Buffer tlv2711;
 		if ( m_message.messageType() == Oscar::MessageType::File ) //TODO: reduce the amount of magic #s
@@ -342,7 +336,6 @@ void SendMessageTask::addRendezvousMessageData( Buffer* b )
 		b->addLEWord( 0x0000 ); // priority (?)
 	}
 
-
 	b->addLEWord( m_message.textArray().size() + 1 ); // length of string + zero termination
 	b->addString( m_message.textArray() ); // string itself
 	b->addByte( 0x00 ); // zero termination
@@ -397,26 +390,25 @@ QByteArray SendMessageTask::encodeFileName( const QString &fileName, QString &en
 		{
 			if ( (unsigned char)data.at(i) >= 128 )
 			{
-				encodingType = QLatin1String( "iso-8859-1" );
+				encodingType = QStringLiteral( "iso-8859-1" );
 				return data;
 			}
 		}
-		encodingType = QLatin1String( "us-ascii" );
+		encodingType = QStringLiteral( "us-ascii" );
 		return data;
 	}
 	
 	codec = QTextCodec::codecForName( "UTF-8" );
-	encodingType = QLatin1String( "utf-8" );
+	encodingType = QStringLiteral( "utf-8" );
 	return codec->fromUnicode( fileName );
 }
 
-
 /* Old oscarsocket code, which is here for reference in case this doesn't work
-QTextCodec *codec = 0L;
+QTextCodec *codec = nullptr;
 WORD charset = 0x0000; // default to ascii
 WORD charsubset = 0x0000;
 int length = message.length();
-unsigned char *utfMessage = 0L;
+unsigned char *utfMessage = nullptr;
 
 codec=QTextCodec::codecForMib(3); // US-ASCII
 
@@ -509,7 +501,3 @@ if(mIsICQ)
 sendBuf(outbuf,0x02);
 */
 
-
-
-
-//kate: tab-width 4; indent-mode csands;
