@@ -30,9 +30,9 @@ public:
 
     ~SSIParamsTask();
 
-    virtual bool forMe(const Transfer* transfer) const;
-    virtual bool take(Transfer* transfer);
-    virtual void onGo();
+    bool forMe(const Transfer* transfer) const Q_DECL_OVERRIDE;
+    bool take(Transfer* transfer) Q_DECL_OVERRIDE;
+    void onGo() Q_DECL_OVERRIDE;
 
 private:
 	void handleParamReply();
@@ -40,4 +40,3 @@ private:
 
 #endif
 
-// kate: tab-width 4; indent-mode csands;
